<?php
include("../lib/session_on.php");

$session = new session_on(); 

if(isset($_POST['pass'])) {
	$session->start();	
}


$book_array = array(title => "Fast CakePHP" ,limit => "12月31日");

/*smarty*/

require("../lib/smarty.php");
$smarty->assign("title","TOP"); //headerのtitle
$smarty->assign("pagename","index");//pageの名前
$smarty->assign("book_sum",$_COOKIE["TestCookie"]);
$smarty->assign("book_date",$book_array);
$smarty->assign("session_status",$session->getstatus("TestCookie"));
$smarty->display("index.tpl");

